@@ -8,6 +8,7 @@ import re
 
 from ParameterStructure.Instances import InstancePlacementGeometry
 from .config import continue_on_error
+from .utils import sort_references, sort_component_list
 
 from copy import copy
 logger = colorlog.getLogger('PySimultan')
@@ -193,8 +194,6 @@ class List(UserList):
 
     def __init__(self, *args, **kwargs):
         self._wrapped_obj = kwargs.get('wrapped_obj', None)
-        if self._wrapped_obj is not None:
-            self.data = self._wrapped_obj.ContainedComponentsAsList
         self._contained_components = kwargs.get('contained_components', None)
         self._contained_parameters = kwargs.get('contained_parameters', None)
         self._template_parser = kwargs.get('template_parser', None)
@@ -204,6 +203,14 @@ class List(UserList):
             _ = self.contained_components
             _ = self.contained_parameters
 
+    @property
+    def data(self):
+        if self._wrapped_obj is None:
+            return
+        components = self._wrapped_obj.ContainedComponentsAsList
+        indices = sort_component_list(components)
+        return [x for _, x in sorted(zip(indices, components))]
+
     def __getitem__(self, i):
         if isinstance(i, slice):
             if self._template_parser is None:
@@ -247,8 +254,6 @@ class ReferenceList(UserList):
 
     def __init__(self, *args, **kwargs):
         self._wrapped_obj = kwargs.get('wrapped_obj', None)
-        if self._wrapped_obj is not None:
-            self.data = self._wrapped_obj.ReferencedComponents.Items
         self._contained_components = kwargs.get('contained_components', None)
         self._contained_parameters = kwargs.get('contained_parameters', None)
         self._template_parser = kwargs.get('template_parser', None)
@@ -267,6 +272,14 @@ class ReferenceList(UserList):
     def __repr__(self):
         return f'{self.name}: ' + repr(list(self.data))
 
+    @property
+    def data(self):
+        if self._wrapped_obj is None:
+            return
+        ref_components = [x.Reference for x in self._wrapped_obj.ReferencedComponents.Items]
+        indices = sort_references(self._wrapped_obj.ReferencedComponents.Items)
+        return [x for _, x in sorted(zip(indices, ref_components))]
+
     @property
     def contained_components(self):
         if self._contained_components is None:
